<?php

namespace Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Fac00100CalculoDeApuracao extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $crudService;
    protected $parameterBag;
	protected $novoCodigo;
    protected $environment;
    protected $dataSourceManager;

    public function __construct($crudService, $parameterBag, $novoCodigo, $entityManager, $environment, $dataSourceManager) {
        $this->crudService  	= $crudService;
        $this->parameterBag     = $parameterBag;
        $this->novoCodigo  		= $novoCodigo;
        $this->entityManager 	= $entityManager;
    	$this->environment 		= $environment;
    	$this->dataSourceManager= $dataSourceManager;
    }

    public function apurarfaturamento(DTO\Request\DataSet $request, DTO\Response $response){
    	$dataSet = $request->getDataSet();
    	$rows = $dataSet->getRows();
    	$this->apuracNfmProcedure($rows[0], $response);
    }

    private function apuracNfmProcedure($row, $response) {
    	try {
			$procedure = new StoredProcedure($this->entityManager->getConnection(), 'APURAC_NFM');
			$procedure->addParam(new Param('P_FILIAL', Param::PARAM_INPUT, $row['CDFILIAL'], Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDFILIPROC', Param::PARAM_INPUT, $this->environment->getCdFilial(),Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDCIA', Param::PARAM_INPUT, $row['CDCIA'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTFECHAME', Param::PARAM_INPUT, $row['DTFATUR'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTINIAPUR', Param::PARAM_INPUT, $row['DTINICIAL'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_DTFIMAPUR', Param::PARAM_INPUT, $row['DTFINAL'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDSERIE', Param::PARAM_INPUT, $row['CDSERIE'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDTPIJURTRAN', Param::PARAM_INPUT, 'J',Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_NRINSJURTRAN', Param::PARAM_INPUT, NULL,Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_NRVOO', Param::PARAM_INPUT, $row['P_NRVOO'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDAGRUPSERV', Param::PARAM_INPUT, $row['AGRUPSERV'],Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_GRUPPROD', Param::PARAM_INPUT, NULL,Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_IDGRUPTAXA', Param::PARAM_INPUT, 'N',Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_LISTANF', Param::PARAM_INPUT, NULL,Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_CDOPERADOR', Param::PARAM_INPUT, $this->environment->getCdOperador() ,Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $this->environment->getNrOrg(),Param::PARAM_TYPE_STR));
			$procedure->addParam(new Param('P_NRAPURACFATM', Param::PARAM_OUTPUT, null, null, 20));
			$nrapuracfat = $procedure->execute();
			$response->addDataSet($this->getNotas($row['CDFILIAL'], $nrapuracfat));

		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
    	}
    }

    private function getNotas($filial, $nrapuracfat) {
    	$conditions = array(
    		array(
    			"columnName" => "CDFILIAL",
    			"operator" => "=",
    			"value" => $filial
    		),
    		array(
    			"columnName" => "NRAPURACFATM",
    			"operator" => "=",
    			"value" => $nrapuracfat
    		),
    		array(
    			"columnName" => "NRORG",
    			"operator" => "=",
    			"value" => $this->environment->getNrOrg()
    		)
    	);
    	$filterCriteria = new FilterCriteria('fac00100_notafiscal', $conditions);
    	$newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, ["CDFILIAL", "NRAPURACFATM", "NRORG"]);
    	$dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
    	return $dataSet;
    }
}
